<div align="center">

# ◢ &nbsp; PySaRe &nbsp;  ◣

**Python package for neural network-based survival analysis and reliability engineering**

<p>
<img alt="GitHub Last Commit" src="https://img.shields.io/github/last-commit/oholmer/PySaRe" />
<img alt="Version" src="https://img.shields.io/badge/version-0.1-blue" />
<img alt="Github License" src="https://img.shields.io/badge/License-MIT-green.svg" />
</p>

<br />

</div>

# Introduction
PySaRe is a Python package for neural network-based survival analysis and reliability engineering based on PyTorch.
For an introduction to PySaRe, see [examples/quickstart.ipynb](examples/quickstart.ipynb).


# Installation 
PySaRe is available on pip:
```
pip install pysare
```


# Publications
The package is based on the following publications
- **Energy-Based Survival Models for Predictive Maintenance** https://arxiv.org/abs/2302.00629
  
